@@ -8,6 +8,7 @@
 #' Can be set or accessed using \code{\link[geoknife]{version}}
 #' @slot email an email to send finished process alert to
 #' @slot wait boolean for wait until complete (hold up R until processing is complete)
+#' @slot sleep.time numeric for time to wait in between calls to \code{\link{check}}. Only used if \code{wait=TRUE}
 #' @slot processInputs (_private) a list of required and options process inputs, and their 
 #' default values (if specified). This is populated (or repopulated) whenever \code{algorithm} is set.
 #' @slot WPS_SCHEMA_LOCATION (_private) location for web processing service schema
@@ -29,19 +30,23 @@
 setClass(
   Class = "webprocess",
   prototype = prototype(
-    url = 'http://cida.usgs.gov/gdp/process/WebProcessingService', 
-    algorithm = list('Area Grid Statistics (weighted)'=
-                       "gov.usgs.cida.gdp.wps.algorithm.FeatureWeightedGridStatisticsAlgorithm"),
-    version = '1.0.0',
-    email = as.character(NA),
-    wait = FALSE
-    ),
+    version = gconfig('version'),
+    WPS_SCHEMA_LOCATION = 'http://schemas.opengis.net/wps/1.0.0/wpsExecute_request.xsd',
+    WPS_NAMESPACE = 'http://www.opengis.net/wps/1.0.0',
+    XSI_SCHEMA_LOCATION = 'http://www.opengis.net/wfs ../wfs/1.1.0/WFS.xsd',
+    XSI_NAMESPACE = 'http://www.w3.org/2001/XMLSchema-instance',
+    OGC_NAMESPACE = 'http://www.opengis.net/ogc',
+    XLINK_NAMESPACE = 'http://www.w3.org/1999/xlink',
+    OWS_NAMESPACE = 'http://www.opengis.net/ows/1.1',
+    emailK = 'gov.usgs.cida.gdp.wps.algorithm.communication.EmailWhenFinishedAlgorithm'
+  ),
   representation = representation(
     url="character",
     algorithm="list",
     version="character",
     email = "character",
     wait = 'logical',
+    sleep.time = "numeric",
     processInputs="list",
     WPS_SCHEMA_LOCATION="character",
     WPS_NAMESPACE="character",
@@ -61,37 +66,26 @@ setMethod(f="initialize",signature="webprocess",
             algorithm = .Object@algorithm,
             version = .Object@version,
             email = .Object@email,
-            wait = .Object@wait, ...)
+            wait = .Object@wait, 
+            sleep.time = .Object@sleep.time, ...)
             {
-
-            .Object@WPS_SCHEMA_LOCATION <- 'http://schemas.opengis.net/wps/1.0.0/wpsExecute_request.xsd'
-            .Object@WPS_NAMESPACE <- 'http://www.opengis.net/wps/1.0.0'
-            
-            .Object@XSI_SCHEMA_LOCATION <- 'http://www.opengis.net/wfs ../wfs/1.1.0/WFS.xsd'
-            .Object@XSI_NAMESPACE <- 'http://www.w3.org/2001/XMLSchema-instance'
-            
-            .Object@OGC_NAMESPACE <- 'http://www.opengis.net/ogc'
-            .Object@XLINK_NAMESPACE <- 'http://www.w3.org/1999/xlink'
-            
-            .Object@OWS_NAMESPACE <- 'http://www.opengis.net/ows/1.1'
-            
-            .Object@UTILITY_URL <- gsub('process','utility',url)
-            
-            .Object@emailK <- 'gov.usgs.cida.gdp.wps.algorithm.communication.EmailWhenFinishedAlgorithm'
-            
-            .Object@version <- version
-            .Object@url <- url
-            .Object@email <- email
-            .Object@wait <- wait
-            
+          
             # // -- supporting pass through of existing inputs arguments *when* they are applicable.
+            old.algorithm <- if(length(.Object@algorithm) > 0) .Object@algorithm else gconfig('algorithm')
             old.inputs = inputs(.Object)
-            old.algorithm = .Object@algorithm
-            .Object@algorithm <- algorithm
+            
+            #things that use package variables:
+            .Object@url <- if(length(url) > 0) url else gconfig('wps.url')
+            .Object@sleep.time <- if(length(sleep.time) > 0) sleep.time else gconfig('sleep.time')
+            .Object@wait <- if(length(wait) > 0) wait else gconfig('wait')
+            .Object@email <- if(length(email) > 0) email else gconfig('email')
+            .Object@algorithm <- if(length(algorithm) > 0) algorithm else gconfig('algorithm') # will need to do this differently...
+            
+            .Object@UTILITY_URL <- gsub('process','utility', .Object@url)
             
             processInputs <- defaultProcessInputs(algorithm = .Object@algorithm[[1]], .Object@url, .Object@version)
             
-            if (length(old.inputs) && old.algorithm[[1]] == algorithm[[1]]){
+            if (length(old.inputs) > 0 && old.algorithm[[1]] == algorithm[[1]]){
               which.replace <- unlist(unname(lapply(old.inputs, function(x) !is.null(x[[1]]) && !is.na(x[[1]])))) & names(old.inputs) %in% names(processInputs)
               which.to.rplc <- names(processInputs) %in% names(old.inputs[which.replace])
             } else {
@@ -101,7 +95,10 @@ setMethod(f="initialize",signature="webprocess",
             .Object@processInputs  <-	processInputs
             .Object@processInputs[which.to.rplc] <- old.inputs[which.replace]
             
-            inputs(.Object) <- list(...)
+            other.inputs <- list(...)
+            if (any(paste0('.',names(other.inputs)) %in% pkg.env$private.funs))
+              stop('read only variables in webprocess cannot be set', call. = FALSE)
+            inputs(.Object) <- other.inputs
             
             return(.Object)
           })
