@@ -15,5 +15,9 @@ stencil <- simplegeom(data.frame('point1'=c(-89, 46), 'point2'=c(-78.6, 42.2)))
 
 knife = webprocess(algorithm = list('OPeNDAP Subset'="gov.usgs.cida.gdp.wps.algorithm.FeatureCoverageOPeNDAPIntersectionAlgorithm"))
 
-job <- geoknife(stencil,fabric, knife, wait = TRUE)
-file <- download(job, destination = '../prism_data.nc')
\ No newline at end of file
+job <- geoknife(stencil,fabric, knife, wait = TRUE, OUTPUT_TYPE="netcdf")
+file <- download(job, destination = '../prism_data.nc')
+
+knife = webprocess(algorithm = list('OPeNDAP Subset'="gov.usgs.cida.gdp.wps.algorithm.FeatureCoverageOPeNDAPIntersectionAlgorithm"))
+job <- geoknife(stencil,fabric, knife, wait = TRUE, OUTPUT_TYPE="geotiff")
+file <- download(job, destination = '../prism_data.zip')
